unit Main;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  TTapiComponent,
  StdCtrls,
  Spin;

type
  TfrmMain = class(TForm)
    Tapi1: TTapi;
    pnlEntries: TGroupBox;
    Label1: TLabel;
    cboPhonebook: TComboBox;
    cmdNewEntry: TButton;
    cmdEditEntry: TButton;
    cmdRenameEntry: TButton;
    cmdDeleteEntry: TButton;
    pnlCredentials: TGroupBox;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    txtUsername: TEdit;
    txtDomain: TEdit;
    txtPassword: TEdit;
    cmdGetParams: TButton;
    cmdSetParams: TButton;
    pnlActivity: TGroupBox;
    cmdDial: TButton;
    lstActivity: TListBox;
    cmdDisconnect: TButton;
    pnlSettings: TGroupBox;
    chkMinimize: TCheckBox;
    chkSyncDial: TCheckBox;
    spnRedialAttempts: TSpinEdit;
    Label5: TLabel;
    Label6: TLabel;
    spnRedialPause: TSpinEdit;
    procedure Tapi1Connect(Sender: TObject);
    procedure Tapi1ConnectFail(Error: Longint; ErrorString: string);
    procedure Tapi1Disconnect(Error: Longint; ErrorString: string);
    procedure Tapi1Notify(Error: Longint; ErrorString: string);
    procedure cmdDialClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cmdNewEntryClick(Sender: TObject);
    procedure cmdDisconnectClick(Sender: TObject);
    procedure cmdEditEntryClick(Sender: TObject);
    procedure cmdRenameEntryClick(Sender: TObject);
    procedure cmdDeleteEntryClick(Sender: TObject);
    procedure cmdGetParamsClick(Sender: TObject);
    procedure cmdSetParamsClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}

procedure TfrmMain.Tapi1Connect(Sender: TObject);
begin
  cmdDisconnect.Enabled := True;
end;

procedure TfrmMain.Tapi1ConnectFail(Error: Longint; ErrorString: string);
begin
  MessageDlg('Connection Failed!', mtError, [mbOK], 0);
  cmdDial.Enabled := true;
end;

procedure TfrmMain.Tapi1Disconnect(Error: Longint; ErrorString: string);
begin
  Tapi1.Disconnect;
  cmdDial.Enabled := true;
  cmdDisconnect.Enabled := False;
end;

procedure TfrmMain.Tapi1Notify(Error: Longint; ErrorString: string);
begin
  lstActivity.Items.Add(ErrorString + ' (' + IntToStr(Error) + ')');
  lstActivity.ItemIndex := lstActivity.Items.Count - 1;
end;

procedure TfrmMain.cmdDialClick(Sender: TObject);
begin
  With Tapi1 do
  begin
    EntryName := cboPhonebook.Text;
    Username := txtUsername.Text;
    Domain := txtDomain.Text;
    Password := txtPassword.Text;
    MinimizeDialWindow := chkMinimize.Checked;
    SynchronousDial := chkSyncDial.Checked;
    RedialAttempts := spnRedialAttempts.Value;
    RedialPause := spnRedialPause.Value;
  end;
  Try
  begin
    Tapi1.Connect;
    cmdDial.Enabled := False;
  end;
  except
    on E: Exception do
      MessageDlg('An error occurred: ' + E.Message, mtError, [mbOK], 0);
  end;
end;

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  if (Tapi1.RasInitialized) then
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries)
  else
  begin
    MessageDlg('RAS could not be initialized!', mtError, [mbOK], 0);
    pnlEntries.Enabled := False;
    pnlCredentials.Enabled := False;
    pnlSettings.Enabled := False;
    pnlActivity.Enabled := False;
  end;
end;

procedure TfrmMain.cmdNewEntryClick(Sender: TObject);
begin
  if (Tapi1.CreateEntry(Self.Handle)) then
  begin
    Tapi1.GetPhonebookEntries;
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries);
  end
  else
    MessageDlg('Unable to create new entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdDisconnectClick(Sender: TObject);
begin
  Tapi1.Disconnect;
  cmdDial.Enabled := true;
  cmdDisconnect.Enabled := False;
end;

procedure TfrmMain.cmdEditEntryClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;
  if (Not Tapi1.EditEntry(Self.Handle, cboPhonebook.Items[cboPhonebook.ItemIndex])) then
    MessageDlg('Unable to edit new entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdRenameEntryClick(Sender: TObject);
var
  NewName: String;
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  NewName := InputBox('Rename', 'Enter the new entry name:', cboPhonebook.Items[cboPhonebook.ItemIndex]);
  if (NewName = '') or (UpperCase(NewName) = UpperCase(cboPhonebook.Items[cboPhonebook.ItemIndex])) then exit;

  if (Tapi1.RenameEntry(cboPhonebook.Items[cboPhonebook.ItemIndex], NewName)) then
  begin
    Tapi1.GetPhonebookEntries;
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries);
  end
  else
    MessageDlg('Unable to rename entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdDeleteEntryClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  if (MessageDlg('Are you sure you want to delete this entry?', mtConfirmation, [mbYes, mbNo], 0) = mrNo) then exit;

  if (Tapi1.DeleteEntry(cboPhonebook.Items[cboPhonebook.ItemIndex])) then
  begin
    Tapi1.GetPhonebookEntries;
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries);
  end
  else
    MessageDlg('Unable to create new entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdGetParamsClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  if (Tapi1.GetDialParams(cboPhonebook.Items[cboPhonebook.ItemIndex])) then
  begin
    txtUsername.Text := Tapi1.Username;
    txtPassword.Text := Tapi1.Password;
  end
  else
    MessageDlg('Unable to get entry parameters.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdSetParamsClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  Tapi1.Username := txtUsername.Text;
  Tapi1.Password := txtPassword.Text;

  if (Not Tapi1.SetDialParams) then
    MessageDlg('Unable to get entry parameters.', mtError, [mbOK], 0);
end;

procedure TfrmMain.Button1Click(Sender: TObject);
begin
  Tapi1.EnumConnections;
end;

end.
